# Wex Core

Wex core

Version: 6.0.23

## Requirements

- Python >=3.6

## Dependencies

- click
- pip-tools
- pydantic
- pytest
- wexample-app==0.0.25
- wexample-filestate==0.0.28

## Installation

```bash
pip install wexample-wex-core
```

## Links

- Homepage: https://github.com/wexample/wexample-wex-core

## License

MIT
## Credits

This package has been developed by [Wexample](https://wexample.com), a collection of tools and utilities to streamline development workflows.

Visit [wexample.com](https://wexample.com) to discover more tools and resources for efficient development.